==> kxmleditor-0.7.2.tar.gz: kxmleditor-0.7.2/part/dcopiface_part_ro_skel.cpp <==
/****************************************************************************
**
** DCOP Skeleton created by dcopidl2cpp from dcopiface_part_ro.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "./dcopiface_part_ro.h"

#include <kdatastream.h>


static const char* const KXMLEditorPartIfaceReadOnly_ftable[4][3] = {
    { "QString", "saveAsFile(QString)", "saveAsFile(QString path_to_file)" },
    { "QString", "selectNode(QString)", "selectNode(QString pathToNode)" },
    { "QString", "currentNode()", "currentNode()" },
    { 0, 0, 0 }
};

bool KXMLEditorPartIfaceReadOnly::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KXMLEditorPartIfaceReadOnly_ftable[0][1] ) { // QString saveAsFile(QString)
	QString arg0;
	QDataStream arg( data, IO_ReadOnly );
	arg >> arg0;
	replyType = KXMLEditorPartIfaceReadOnly_ftable[0][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << saveAsFile(arg0 );
    } else if ( fun == KXMLEditorPartIfaceReadOnly_ftable[1][1] ) { // QString selectNode(QString)
	QString arg0;
	QDataStream arg( data, IO_ReadOnly );
	arg >> arg0;
	replyType = KXMLEditorPartIfaceReadOnly_ftable[1][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << selectNode(arg0 );
    } else if ( fun == KXMLEditorPartIfaceReadOnly_ftable[2][1] ) { // QString currentNode()
	replyType = KXMLEditorPartIfaceReadOnly_ftable[2][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << currentNode( );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return TRUE;
}

QCStringList KXMLEditorPartIfaceReadOnly::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "KXMLEditorPartIfaceReadOnly";
    return ifaces;
}

QCStringList KXMLEditorPartIfaceReadOnly::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; KXMLEditorPartIfaceReadOnly_ftable[i][2]; i++ ) {
	QCString func = KXMLEditorPartIfaceReadOnly_ftable[i][0];
	func += ' ';
	func += KXMLEditorPartIfaceReadOnly_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


#include <kdatastream.h>


static const char* const KXMLEditorPartIfaceReadWrite_ftable[3][3] = {
    { "QString", "openURL(QString)", "openURL(QString szURL)" },
    { "QString", "close()", "close()" },
    { 0, 0, 0 }
};

bool KXMLEditorPartIfaceReadWrite::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KXMLEditorPartIfaceReadWrite_ftable[0][1] ) { // QString openURL(QString)
	QString arg0;
	QDataStream arg( data, IO_ReadOnly );
	arg >> arg0;
	replyType = KXMLEditorPartIfaceReadWrite_ftable[0][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << openURL(arg0 );
    } else if ( fun == KXMLEditorPartIfaceReadWrite_ftable[1][1] ) { // QString close()
	replyType = KXMLEditorPartIfaceReadWrite_ftable[1][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << close( );
    } else {
	return KXMLEditorPartIfaceReadOnly::process( fun, data, replyType, replyData );
    }
    return TRUE;
}

QCStringList KXMLEditorPartIfaceReadWrite::interfaces()
{
    QCStringList ifaces = KXMLEditorPartIfaceReadOnly::interfaces();
    ifaces += "KXMLEditorPartIfaceReadWrite";
    return ifaces;
}

QCStringList KXMLEditorPartIfaceReadWrite::functions()
{
    QCStringList funcs = KXMLEditorPartIfaceReadOnly::functions();
    for ( int i = 0; KXMLEditorPartIfaceReadWrite_ftable[i][2]; i++ ) {
	QCString func = KXMLEditorPartIfaceReadWrite_ftable[i][0];
	func += ' ';
	func += KXMLEditorPartIfaceReadWrite_ftable[i][2];
	funcs << func;
    }
    return funcs;
}

==> kxmleditor_1.1.4.orig.tar.gz: kxmleditor-1.1.4/part/dcopiface_part_ro_skel.cpp <==
/****************************************************************************
**
** DCOP Skeleton created by dcopidl2cpp from dcopiface_part_ro.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "dcopiface_part_ro.h"

#include <kdatastream.h>


static const char* const KXMLEditorPartIfaceReadOnly_ftable[4][3] = {
    { "QString", "saveAsFile(QString)", "saveAsFile(QString path_to_file)" },
    { "QString", "selectNode(QString)", "selectNode(QString pathToNode)" },
    { "QString", "currentNode()", "currentNode()" },
    { 0, 0, 0 }
};
static const int KXMLEditorPartIfaceReadOnly_ftable_hiddens[3] = {
    0,
    0,
    0,
};

bool KXMLEditorPartIfaceReadOnly::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KXMLEditorPartIfaceReadOnly_ftable[0][1] ) { // QString saveAsFile(QString)
	QString arg0;
	QDataStream arg( data, IO_ReadOnly );
	arg >> arg0;
	replyType = KXMLEditorPartIfaceReadOnly_ftable[0][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << saveAsFile(arg0 );
    } else if ( fun == KXMLEditorPartIfaceReadOnly_ftable[1][1] ) { // QString selectNode(QString)
	QString arg0;
	QDataStream arg( data, IO_ReadOnly );
	arg >> arg0;
	replyType = KXMLEditorPartIfaceReadOnly_ftable[1][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << selectNode(arg0 );
    } else if ( fun == KXMLEditorPartIfaceReadOnly_ftable[2][1] ) { // QString currentNode()
	replyType = KXMLEditorPartIfaceReadOnly_ftable[2][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << currentNode( );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList KXMLEditorPartIfaceReadOnly::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "KXMLEditorPartIfaceReadOnly";
    return ifaces;
}

QCStringList KXMLEditorPartIfaceReadOnly::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; KXMLEditorPartIfaceReadOnly_ftable[i][2]; i++ ) {
	if (KXMLEditorPartIfaceReadOnly_ftable_hiddens[i])
	    continue;
	QCString func = KXMLEditorPartIfaceReadOnly_ftable[i][0];
	func += ' ';
	func += KXMLEditorPartIfaceReadOnly_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


#include <kdatastream.h>


static const char* const KXMLEditorPartIfaceReadWrite_ftable[3][3] = {
    { "QString", "openURL(QString)", "openURL(QString szURL)" },
    { "QString", "close()", "close()" },
    { 0, 0, 0 }
};
static const int KXMLEditorPartIfaceReadWrite_ftable_hiddens[2] = {
    0,
    0,
};

bool KXMLEditorPartIfaceReadWrite::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KXMLEditorPartIfaceReadWrite_ftable[0][1] ) { // QString openURL(QString)
	QString arg0;
	QDataStream arg( data, IO_ReadOnly );
	arg >> arg0;
	replyType = KXMLEditorPartIfaceReadWrite_ftable[0][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << openURL(arg0 );
    } else if ( fun == KXMLEditorPartIfaceReadWrite_ftable[1][1] ) { // QString close()
	replyType = KXMLEditorPartIfaceReadWrite_ftable[1][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << close( );
    } else {
	return KXMLEditorPartIfaceReadOnly::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList KXMLEditorPartIfaceReadWrite::interfaces()
{
    QCStringList ifaces = KXMLEditorPartIfaceReadOnly::interfaces();
    ifaces += "KXMLEditorPartIfaceReadWrite";
    return ifaces;
}

QCStringList KXMLEditorPartIfaceReadWrite::functions()
{
    QCStringList funcs = KXMLEditorPartIfaceReadOnly::functions();
    for ( int i = 0; KXMLEditorPartIfaceReadWrite_ftable[i][2]; i++ ) {
	if (KXMLEditorPartIfaceReadWrite_ftable_hiddens[i])
	    continue;
	QCString func = KXMLEditorPartIfaceReadWrite_ftable[i][0];
	func += ' ';
	func += KXMLEditorPartIfaceReadWrite_ftable[i][2];
	funcs << func;
    }
    return funcs;
}
